@@ -3,10 +3,11 @@
 from trojanvision.attacks import PGD
 from trojanvision.environ import env
 from trojanzoo.defenses import Defense
-from trojanzoo.utils import repeat_to_batch, to_list, cos_sim
+from trojanzoo.utils.tensor import repeat_to_batch
 from trojanzoo.utils.output import prints
 
 import torch
+import torch.nn as nn
 import torch.autograd
 import torch.nn.functional as F
 import argparse
@@ -59,13 +60,20 @@ class AdvMind(Defense):
         self.true_query_num: int = self.attack.query_num - self.fake_query_num
         self.attack_grad_list: list[torch.Tensor] = []
 
+        self.cos_sim = nn.CosineSimilarity()
+
     def detect(self):
-        zeros = torch.zeros(self.attack.iteration - 1)
-        result_dict = {'draw': zeros.clone(), 'win': zeros.clone(), 'lose': zeros.clone()}
+        zeros = [0] * (self.attack.iteration - 1)
+        result_dict = {'draw': zeros.copy(), 'win': zeros.copy(), 'lose': zeros.copy()}
         counter = 0
         attack_succ_num = 0.
         detect_succ_num = 0.
-        for i, data in enumerate(self.dataset.loader['test']):
+
+        validset = self.dataset.get_dataset('valid')
+        testset, _ = self.dataset.split_dataset(validset, percent=0.3)
+        loader = self.dataset.get_dataloader(mode='valid', dataset=testset,
+                                             batch_size=1, shuffle=True)
+        for i, data in enumerate(loader):
             if counter >= 200:
                 break
             print('img idx: ', i)
@@ -86,9 +94,9 @@ class AdvMind(Defense):
                 detect_succ_num += 1
             attack_succ_rate = attack_succ_num / counter
             detect_succ_rate = detect_succ_num / counter
-            print('draw: ', to_list(result_dict['draw']))
-            print('win : ', to_list(result_dict['win']))
-            print('lose: ', to_list(result_dict['lose']))
+            print('draw: ', result_dict['draw'])
+            print('win : ', result_dict['win'])
+            print('lose: ', result_dict['lose'])
             print()
             print('total: ', counter)
             print('attack succ rate: ', attack_succ_rate)
@@ -108,7 +116,7 @@ class AdvMind(Defense):
         # seq_centers: (iter, 1, C, H, W)   seq_bias: (iter)
         # seq_centers = seq[:, 0]  # debug
         if 'start' in self.output:
-            mean_error = (seq_centers[:, 0] - seq[:, 0]).abs().flatten(start_dim=1).max(dim=1)[0]
+            mean_error = (seq_centers[:, 0] - seq[:, 0]).abs().flatten(start_dim=1).amax(dim=1)
             print('Mean Shift Distance: '.ljust(25) +
                   f'avg {mean_error.mean():<10.5f} min {mean_error.min():<10.5f} max {mean_error.max():<10.5f}')
             print('Bias Estimation: '.ljust(25) +
@@ -116,7 +124,7 @@ class AdvMind(Defense):
         # candidate_centers = self.get_candidate_centers(seq, seq_centers, seq_bias)  # abandoned
         # candidate_centers = seq_centers
         detect_result = self.get_detect_result(seq_centers, target=target)
-        attack_result = self.model(seq[:, 0].squeeze()).argmax(dim=1)
+        attack_result = self.model(seq[:, 0]).argmax(dim=1).detach().cpu()
 
         attack_succ = self.attack.iteration
         detect_succ = self.attack.iteration
@@ -127,7 +135,8 @@ class AdvMind(Defense):
                     attack_result[min(i + 1, self.attack.iteration - 2)] == target and \
                     attack_succ == self.attack.iteration:
                 attack_succ = i
-            if detect_result[i] == detect_result[min(i + 1, self.attack.iteration - 2)] and detect_succ == self.attack.iteration and detect_true:
+            if (detect_true and detect_result[i] == detect_result[min(i + 1, self.attack.iteration - 2)]
+                    and detect_succ == self.attack.iteration):
                 if detect_result[i] == target:
                     detect_succ = i
                 else:
@@ -135,9 +144,9 @@ class AdvMind(Defense):
         if 'end' in self.output:
             # print('candidate centers: ', [len(i) for i in candidate_centers])
             print('Detect Iter: ', detect_succ)
-            prints(to_list(detect_result), indent=12)
+            prints(detect_result.tolist(), indent=12)
             print('Attack Iter: ', attack_succ)
-            prints(to_list(attack_result), indent=12)
+            prints(attack_result.tolist(), indent=12)
             print()
         result = ['draw'] * (self.attack.iteration - 1)
         if attack_succ < detect_succ:
@@ -155,7 +164,7 @@ class AdvMind(Defense):
     def get_seq(self, _input: torch.Tensor, target: torch.Tensor) -> torch.Tensor:
         seq = []
         X = _input.clone()
-        noise = torch.zeros_like(_input)
+        noise: torch.Tensor = torch.zeros_like(_input)
         if isinstance(target, int):
             target = target * torch.ones(len(_input), dtype=torch.long, device=_input.device)
 
@@ -171,7 +180,7 @@ class AdvMind(Defense):
                 self.hess = self.calc_hess(loss_fn, X, sigma=self.attack.sigma,
                                            hess_b=self.hess_b, hess_lambda=self.hess_lambda)
                 self.hess /= self.hess.norm(p=2)
-            cluster = self.attack.gen_seq(X, query_num=self.true_query_num)
+            cluster = self.attack.gen_seq(X, query_num=self.true_query_num)[:, 0]  # (query_num+1, C, H, W)
             # Attack Adaptive
             if self.attack_adapt:
                 fake_seq = self.get_fake_seq(X=X)
@@ -210,7 +219,7 @@ class AdvMind(Defense):
             noise = (noise - self.attack.pgd_alpha * grad).clamp(-self.attack.pgd_eps, self.attack.pgd_eps)
             X = (_input + noise).clamp(0, 1)
             noise = X - _input
-        return torch.stack(seq)
+        return torch.stack(seq)  # (iter, query_num+1, C, H, W)
 
     def get_fake_seq(self, X: torch.Tensor) -> torch.Tensor:
         if X.dim() == 4:
@@ -256,7 +265,7 @@ class AdvMind(Defense):
         return torch.stack(seq_centers), torch.stack(seq_bias)
 
     def get_detect_result(self, seq_centers: torch.Tensor, target=None):
-        pair_seq = -torch.ones(self.attack.iteration - 1, dtype=torch.long, device=env['device'])
+        pair_seq = -torch.ones(self.attack.iteration - 1, dtype=torch.long)
         detect_prob = torch.ones(self.model.num_classes) / self.model.num_classes
         for i in range(len(seq_centers) - 1):
             X: torch.Tensor = seq_centers[i].clone()
@@ -266,7 +275,7 @@ class AdvMind(Defense):
                 _label = _class * torch.ones(len(X), dtype=torch.long, device=X.device)
                 X.requires_grad_()
                 loss = self.model.loss(X, _label)
-                grad = torch.autograd.grad(loss, X)[0]
+                grad: torch.Tensor = torch.autograd.grad(loss, X)[0]
                 X.requires_grad = False
                 grad /= grad.abs().max()
                 if self.active:
@@ -281,16 +290,16 @@ class AdvMind(Defense):
                         (1 - self.active_percent) * grad
                 grad.sign_()
                 vec = seq_centers[i + 1] - X
-                dist = cos_sim(-grad, vec)
+                dist = self.cos_sim(-grad.flatten(), vec.flatten())
                 dist_list[_class] = dist
                 if 'middle' in self.output and _class == target:
-                    print('sim <vec, real>: ', cos_sim(vec, -grad))
+                    print('sim <vec, real>: ', self.cos_sim(vec.flatten(), -grad.flatten()))
                     print('sim <est, real>: ',
-                          cos_sim(self.attack_grad_list[i], grad))
+                          self.cos_sim(self.attack_grad_list[i].flatten(), grad.flatten()))
                     print('sim <vec, est>: ',
-                          cos_sim(vec, -self.attack_grad_list[i]))
+                          self.cos_sim(vec.flatten(), -self.attack_grad_list[i].flatten()))
             # todo: Use atanh for normalization after pytorch 1.6
-            detect_prob = F.softmax(torch.log((2 / (1 - dist_list)).sub(1)))
+            detect_prob = torch.log((2 / (1 - dist_list)) - 1).softmax(0)
             # detect_prob.div_(detect_prob.norm(p=2))
             pair_seq[i] = detect_prob.argmax().item()
         return pair_seq
@@ -314,8 +323,8 @@ class AdvMind(Defense):
             #     sub_seq.append(point)
 
             # sub_seq: list[torch.Tensor] = []
-            # idx = float(to_tensor([(x-seq_centers[i]).norm(p=2)
-            #                  for x in seq[i]]).argmin())
+            # idx = torch.tensor([(x - seq_centers[i]).norm(p=2).item()
+            #                     for x in seq[i]]).argmin().item()
             # sub_seq.append(seq[i][idx])
             # norms = [(x - seq_centers[i]).norm(p=2) for x in sub_seq]
             norms: torch.Tensor = (seq - seq_centers[i]).flatten(1).norm(p=2, dim=-1)
@@ -339,8 +348,9 @@ class AdvMind(Defense):
                 #         if _result[j] < 0 and j > i:
                 #             sub_pair_seq.append((j-i) % self.num_classes)
                 # print(vec.view(-1)[:self.num_classes])
+                point: torch.Tensor
                 x = point.clone()
-                dist_list = torch.zeros(self.model.num_classes)
+                dist_list: torch.Tensor = torch.zeros(self.model.num_classes)
                 # print('bound: ', estimate_error + shift_dist)
                 for _class in range(self.model.num_classes):
                     x.requires_grad_()
@@ -358,7 +368,7 @@ class AdvMind(Defense):
                             (1 - self.active_percent) * grad
                         grad.sign_()
                     vec = seq_centers[i + 1] - point
-                    dist = cos_sim(-grad, vec)
+                    dist = self.cos_sim(-grad.flatten(), vec.flatten())
                     dist_list[_class] = dist
                 sub_pair_seq.append(dist_list.argmax().item())
             pair_seq.append(sub_pair_seq)
