@@ -1,4 +1,7 @@
 #!/usr/bin/env python3
+
+# https://github.com/pytorch/examples/blob/main/mnist/main.py
+
 from trojanvision.models.imagemodel import _ImageModel, ImageModel
 
 import torch.nn as nn
@@ -11,17 +14,17 @@ class _Net(_ImageModel):
         super().__init__(**kwargs)
         self.features = nn.Sequential(OrderedDict([
             ('conv1', nn.Conv2d(1, 32, 3, 1)),
-            ('relu1', nn.ReLU()),
+            ('relu1', nn.ReLU(True)),
             ('conv2', nn.Conv2d(32, 64, 3, 1)),
-            ('relu2', nn.ReLU()),
+            ('relu2', nn.ReLU(True)),
         ]))
         self.pool = nn.MaxPool2d(2)
         self.classifier = nn.Sequential(OrderedDict([
             ('dropout1', nn.Dropout(0.25)),
-            ('fc1', self.classifier.fc1),
-            ('relu1', self.classifier.relu1),
+            ('fc1', nn.Linear(9216, 128)),
+            ('relu1', nn.ReLU(True)),
             ('dropout2', nn.Dropout(0.5)),
-            ('fc2', self.classifier.fc2),
+            ('fc2', nn.Linear(128, self.num_classes)),
         ]))
 
 
@@ -29,4 +32,4 @@ class Net(ImageModel):
     available_models = ['net']
 
     def __init__(self, name: str = 'net', model: type[_Net] = _Net, **kwargs):
-        super().__init__(name=name, model=model, num_features=[9216, 128], **kwargs)
+        super().__init__(name=name, model=model, **kwargs)
