@@ -11,7 +11,6 @@ import torch.nn as nn
 from torchvision.models.resnet import conv1x1, conv3x3
 
 from collections.abc import Callable
-from typing import Optional
 
 
 class Bottleneck(nn.Module):
@@ -21,7 +20,7 @@ class Bottleneck(nn.Module):
                  groups: int = 1,
                  base_width: int = 64,
                  dilation: int = 1,
-                 norm_layer: Optional[Callable[..., nn.Module]] = None) -> None:
+                 norm_layer: None | Callable[..., nn.Module] = None) -> None:
         super().__init__()
         if norm_layer is None:
             norm_layer = nn.BatchNorm2d
@@ -75,8 +74,8 @@ class DPN(nn.Module):
                  zero_init_residual: bool = False,
                  groups: int = 1,
                  width_per_group: int = 64,
-                 replace_stride_with_dilation: Optional[list[bool]] = None,
-                 norm_layer: Optional[Callable[..., nn.Module]] = None,
+                 replace_stride_with_dilation: None | list[bool] = None,
+                 norm_layer: None | Callable[..., nn.Module] = None,
                  small: bool = False) -> None:
         super().__init__()
         if norm_layer is None:
@@ -110,21 +109,23 @@ class DPN(nn.Module):
         self.fc = nn.Linear(out_planes[3] + (layers[3] + 1) * dense_depth[3], num_classes)
 
         for m in self.modules():
-            if isinstance(m, nn.Conv2d):
-                nn.init.kaiming_normal_(m.weight, mode='fan_out', nonlinearity='relu')
-            elif isinstance(m, (nn.BatchNorm2d, nn.GroupNorm)):
-                nn.init.constant_(m.weight, 1)
-                nn.init.constant_(m.bias, 0)
+            match m:
+                case nn.Conv2d():
+                    nn.init.kaiming_normal_(m.weight, mode='fan_out', nonlinearity='relu')
+                case nn.BatchNorm2d() | nn.GroupNorm():
+                    nn.init.constant_(m.weight, 1)
+                    nn.init.constant_(m.bias, 0)
 
         # Zero-initialize the last BN in each residual branch,
         # so that the residual branch starts with zeros, and each residual block behaves like an identity.
         # This improves the model by 0.2~0.3% according to https://arxiv.org/abs/1706.02677
         if zero_init_residual:
             for m in self.modules():
-                if isinstance(m, Bottleneck):
-                    nn.init.constant_(m.bn3.weight, 0)  # type: ignore[arg-type]
-                # elif isinstance(m, BasicBlock):
-                #     nn.init.constant_(m.bn2.weight, 0)  # type: ignore[arg-type]
+                match m:
+                    case Bottleneck():
+                        nn.init.constant_(m.bn3.weight, 0)  # type: ignore[arg-type]
+                    # case BasicBlock():
+                    #     nn.init.constant_(m.bn2.weight, 0)  # type: ignore[arg-type]
 
     def _make_layer(self, block: type[Bottleneck], planes: int, blocks: int,
                     out_planes: int, dense_depth: int,
