@@ -2,9 +2,8 @@
 
 from trojanzoo.configs import config
 from trojanzoo.environ import env
-from trojanzoo.utils.data import (dataset_to_tensor,
-                                  split_dataset, get_class_subset)
-from trojanzoo.utils.module import get_name, BasicObject
+from trojanzoo.utils.data import get_class_subset, split_dataset
+from trojanzoo.utils.module import BasicObject, get_name
 from trojanzoo.utils.output import ansi
 
 import torch
@@ -32,7 +31,7 @@ class Dataset(ABC, BasicObject):
         For users, please use :func:`create` instead, which is more user-friendly.
 
     Args:
-        batch_size (int): Batch size of training and validation set
+        batch_size (int): Batch size of training set
             (negative number means batch size for each gpu).
         valid_batch_size (int): Batch size of validation set.
             Defaults to ``100``.
@@ -442,19 +441,17 @@ class Dataset(ABC, BasicObject):
             else os.path.join(self.folder_path, 'loss_weights.npy')
         if os.path.exists(file_path):
             loss_weights = np.load(file_path)
-            return torch.from_numpy(loss_weights).to(device=env['device'])
         else:
             if verbose:
                 print('Calculating Loss Weights')
             dataset = self.get_dataset('train', transform=None)
-            _, targets = dataset_to_tensor(dataset)
-            loss_weights = np.reciprocal(np.bincount(
-                targets.numpy()))     # TODO: linting problem
+            targets = np.array(list(zip(*dataset))[1])
+            loss_weights = np.reciprocal(np.bincount(targets).astype(float))
             assert len(loss_weights) == self.num_classes
             np.save(file_path, loss_weights)
             if verbose:
                 print('Loss Weights Saved at ', file_path)
-            return torch.from_numpy(loss_weights).to(device=env['device'])
+        return torch.from_numpy(loss_weights).to(device=env['device'], dtype=torch.float)
 
 
 def add_argument(parser: argparse.ArgumentParser, dataset_name: str = None,
