@@ -318,9 +318,9 @@ class Model(BasicObject):
 
         match loss_weights:
             case np.ndarray():
-                loss_weights = torch.from_numpy(loss_weights).to(device=env['device'])
+                loss_weights = torch.from_numpy(loss_weights).to(device=env['device'], dtype=torch.float)
             case torch.Tensor():
-                loss_weights = loss_weights.to(device=env['device'])
+                loss_weights = loss_weights.to(device=env['device'], dtype=torch.float)
 
         self.loss_weights = loss_weights
         self.layer_name_list: list[str] = None
@@ -547,9 +547,16 @@ class Model(BasicObject):
                 of :any:`torch.nn.Sequential`.
                 If ``False``, will traverse children of all :any:`torch.nn.Module`.
                 Defaults to ``False``.
-            verbose (bool): Whether to show verbose information
-                including layer names and output shape.
-                Defaults to ``True``.
+            verbose (bool): The output level to show information
+                including layer name, output shape and module information.
+                Setting it larger than ``0`` will enable the output.
+                Different integer values stands for different module information.
+                Defaults to ``0``.
+
+                * ``0``: No output
+                * ``1``: Show layer class name.
+                * ``2``: Show layer string (first line).
+                * ``3``: Show layer string (full).
 
         Returns:
             dict[str, torch.Tensor]: The dict of all layer outputs.
@@ -624,8 +631,8 @@ class Model(BasicObject):
                 if :attr:`_output` is not provided.
 
         Returns:
-            torch.Tensor: A scalar loss tensor
-                (with shape ``(N)`` if ``reduction='none'``).
+            torch.Tensor:
+                A scalar loss tensor (with shape ``(N)`` if ``reduction='none'``).
         """
         criterion = self.criterion_noreduction if reduction == 'none' \
             else self.criterion
@@ -1300,13 +1307,13 @@ class Model(BasicObject):
         r"""Remove misclassified samples in a data batch.
 
         Args:
-            data (tuple[torch.Tensor, torch.Tensor]): The data to process
-                with shape ``(N, *)``.
+            data (tuple[torch.Tensor, torch.Tensor]):
+                The input and label to process with shape ``(N, *)`` and ``(N)``.
             **kwargs: Keyword arguments passed to :meth:`get_data`.
 
         Returns:
-            (torch.Tensor, torch.Tensor): The processed data
-                with shape ``(N - k, *)``.
+            (torch.Tensor, torch.Tensor):
+                The processed input and label with shape ``(N - k, *)`` and ``(N - k)``.
         """
         _input, _label = self.get_data(data, **kwargs)
         _classification = self.get_class(_input)
