@@ -9,7 +9,7 @@ from trojanzoo.utils.output import ansi, prints
 from trojanzoo.utils.fim import KFAC, EKFAC
 
 from typing import TYPE_CHECKING
-from typing import Any, Union
+from typing import Any
 from trojanzoo.configs import Config    # TODO: python 3.10
 from trojanzoo.datasets import Dataset
 from torch.optim.optimizer import Optimizer
@@ -142,7 +142,7 @@ class Trainer(BasicObject):
                  optimizer: Optimizer = None,
                  lr_scheduler: _LRScheduler = None,
                  model_ema: ExponentialMovingAverage = None,
-                 pre_conditioner: Union[KFAC, EKFAC] = None,
+                 pre_conditioner: None | KFAC | EKFAC = None,
                  writer=None, **kwargs):
         super().__init__(**kwargs)
         self.param_list['trainer'] = ['optim_args', 'train_args', 'writer_args',
@@ -221,12 +221,12 @@ def add_argument(parser: argparse.ArgumentParser,
     return ClassType.add_argument(group)
 
 
-def create(dataset_name: str = None,
-           dataset: Union[str, Dataset] = None,
-           model: Model = None,
-           model_ema: bool = False,
-           pre_conditioner: str = None,
-           tensorboard: bool = None,
+def create(dataset_name: None | str = None,
+           dataset: None | str | Dataset = None,
+           model: None | Model = None,
+           model_ema: None | bool = False,
+           pre_conditioner: None | str = None,
+           tensorboard: None | bool = None,
            ClassType: type[Trainer] = Trainer,
            config: Config = config, **kwargs):
     r"""
@@ -238,7 +238,7 @@ def create(dataset_name: str = None,
     Args:
         dataset_name (str): The dataset name.
         dataset (str | trojanzoo.datasets.Dataset):
-            Dataset Instance
+            Dataset instance
             (required for :attr:`model_ema`)
             or dataset name
             (as the alias of `dataset_name`).
@@ -286,10 +286,11 @@ def create(dataset_name: str = None,
     optimizer, lr_scheduler = model.define_optimizer(**optim_args)
 
     module = model._model
-    if optim_args['parameters'] == 'features':
-        module = module.features
-    elif optim_args['parameters'] == 'classifier':
-        module = module.classifier
+    match optim_args['parameters']:
+        case 'features':
+            module = module.features
+        case 'classifier':
+            module = module.classifier
 
     # https://github.com/pytorch/vision/blob/main/references/classification/train.py
     model_ema_module = None
@@ -307,11 +308,13 @@ def create(dataset_name: str = None,
         model_ema_module = ExponentialMovingAverage(
             model._model, decay=1.0 - alpha)
 
-    kfac_optimizer = None
-    if pre_conditioner == 'kfac':   # TODO: python 3.10 match
-        kfac_optimizer = KFAC(module)
-    elif pre_conditioner == 'ekfac':
-        kfac_optimizer = EKFAC(module)
+    match pre_conditioner:
+        case 'kfac':
+            kfac_optimizer = KFAC(module)
+        case 'ekfac':
+            kfac_optimizer = EKFAC(module)
+        case _:
+            kfac_optimizer = None
 
     writer = None
     writer_args: dict[str, Any] = {}
