@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
 
-from .fim import fim_diag, fim
+from .fim import fim_diag, old_fim, new_fim
 from .kfac import KFAC, BaseKFAC, BaseState, KFACState
 from .ekfac import EKFAC
