@@ -8,16 +8,20 @@ import torch
 import torch.nn as nn
 import torch.nn.functional as F
 
-from typing import Optional
-
 
 class EKFACState(BaseState):
+    r"""A storage class for :class:`EKFAC`.
+
+    Attributes:
+        kfe_x (torch.Tensor): ``(in [* kh * kw] + 1, in [* kh * kw] + 1)``.
+        kfe_gy (torch.Tensor): ``(out, out)``.
+        m2 (torch.Tensor): ``(out, in [* kh * kw] + 1 {, kh, kw})``.
+    """
     def __init__(self):
         super().__init__()
-        # (in [* kh * kw] + 1, in [* kh * kw] + 1)
         self.kfe_x: torch.Tensor = None
-        self.kfe_gy: torch.Tensor = None    # (out, out)
-        self.m2: torch.Tensor = None  # (out, in [* kh * kw] + 1 {, kh, kw})
+        self.kfe_gy: torch.Tensor = None
+        self.m2: torch.Tensor = None
 
 
 class EKFAC(BaseKFAC):
@@ -81,21 +85,21 @@ class EKFAC(BaseKFAC):
         return filter_conv
 
     def precond_sua(self, mod: nn.Conv2d, weight_grad: torch.Tensor,
-                    bias_grad: Optional[torch.Tensor]
-                    ) -> tuple[torch.Tensor, Optional[torch.Tensor]]:
+                    bias_grad: None | torch.Tensor
+                    ) -> tuple[torch.Tensor, None | torch.Tensor]:
         precond_func = self._precond_sua_ra if self.ra \
             else self._precond_intra_sua
         return precond_func(mod, weight_grad, bias_grad)
 
     def precond_nosua(self, mod: LayerType, weight_grad: torch.Tensor,
-                      bias_grad: Optional[torch.Tensor]
-                      ) -> tuple[torch.Tensor, Optional[torch.Tensor]]:
+                      bias_grad: None | torch.Tensor
+                      ) -> tuple[torch.Tensor, None | torch.Tensor]:
         precond_func = self._precond_ra if self.ra else self._precond_intra
         return precond_func(mod, weight_grad, bias_grad)
 
     def _precond_sua_ra(self, mod: nn.Conv2d, weight_grad: torch.Tensor,
-                        bias_grad: Optional[torch.Tensor]
-                        ) -> tuple[torch.Tensor, Optional[torch.Tensor]]:
+                        bias_grad: None | torch.Tensor
+                        ) -> tuple[torch.Tensor, None | torch.Tensor]:
         state = self.state_storage[mod]
         g, gb = weight_grad, bias_grad
         s = weight_grad.size()    # (out, in, kh, kw)
@@ -120,8 +124,8 @@ class EKFAC(BaseKFAC):
         return g, gb
 
     def _precond_intra_sua(self, mod: nn.Conv2d, weight_grad: torch.Tensor,
-                           bias_grad: Optional[torch.Tensor]
-                           ) -> tuple[torch.Tensor, Optional[torch.Tensor]]:
+                           bias_grad: None | torch.Tensor
+                           ) -> tuple[torch.Tensor, None | torch.Tensor]:
         state = self.state_storage[mod]
         g, gb = weight_grad, bias_grad
         s = weight_grad.size()    # (out, in, kh, kw)
@@ -164,8 +168,8 @@ class EKFAC(BaseKFAC):
         return g, gb
 
     def _precond_ra(self, mod: nn.Conv2d, weight_grad: torch.Tensor,
-                    bias_grad: Optional[torch.Tensor]
-                    ) -> tuple[torch.Tensor, Optional[torch.Tensor]]:
+                    bias_grad: None | torch.Tensor
+                    ) -> tuple[torch.Tensor, None | torch.Tensor]:
         state = self.state_storage[mod]
         g, gb = weight_grad, bias_grad
         g = g.flatten(1)  # (out, in * kh * kw)
@@ -188,8 +192,8 @@ class EKFAC(BaseKFAC):
         return g, gb
 
     def _precond_intra(self, mod: nn.Conv2d, weight_grad: torch.Tensor,
-                       bias_grad: Optional[torch.Tensor]
-                       ) -> tuple[torch.Tensor, Optional[torch.Tensor]]:
+                       bias_grad: None | torch.Tensor
+                       ) -> tuple[torch.Tensor, None | torch.Tensor]:
         state = self.state_storage[mod]
         g, gb = weight_grad, bias_grad
 
