@@ -2,7 +2,7 @@
 
 import torch
 import torch.nn as nn
-# from torch.nn.utils import _stateless
+from torch.nn.utils import _stateless
 
 from typing import Iterable
 
@@ -35,9 +35,9 @@ def fim_diag(module: nn.Module, _input: torch.Tensor,
     return fim_list
 
 
-def fim(module: nn.Module, _input: torch.Tensor,
-        parameters: Iterable[nn.Parameter] = None
-        ) -> list[torch.Tensor]:
+def old_fim(module: nn.Module, _input: torch.Tensor,
+            parameters: Iterable[nn.Parameter] = None
+            ) -> list[torch.Tensor]:
     if parameters is None:
         parameters = tuple(module.parameters())
     _output: torch.Tensor = module(_input)  # (N, C)
@@ -63,34 +63,34 @@ def fim(module: nn.Module, _input: torch.Tensor,
     return fim_list
 
 
-# def new_fim(module: nn.Module, _input: torch.Tensor,
-#             parameters: Union[dict[str, nn.Parameter],
-#                               Iterable[nn.Parameter]] = None
-#             ) -> list[torch.Tensor]:
-#     if not isinstance(parameters, dict):
-#         id_map: dict[torch.Tensor, str] = {
-#             param.data: name for name, param in module.named_parameters()}
-#         parameters = {id_map[param.data if isinstance(
-#             param, torch.nn.Parameter) else param]: param
-#             for param in parameters}
-#     if parameters is None:
-#         parameters = dict(module.named_parameters())
-#     with torch.no_grad():
-#         _output: torch.Tensor = module(_input)  # (N, C)
-#         prob = _output.softmax(dim=1).unsqueeze(-1).unsqueeze(-1)  # (N, C, 1, 1)
-#     keys, values = zip(*parameters.items())
+def new_fim(module: nn.Module, _input: torch.Tensor,
+            parameters: dict[str, nn.Parameter] | Iterable[nn.Parameter] = None
+            ) -> list[torch.Tensor]:
+    if not isinstance(parameters, dict):
+        id_map: dict[torch.Tensor, str] = {
+            param.data: name for name, param in module.named_parameters()}
+        parameters = {id_map[param.data if isinstance(
+            param, torch.nn.Parameter) else param]: param
+            for param in parameters}
+    if parameters is None:
+        parameters = dict(module.named_parameters())
+    keys, values = zip(*parameters.items())
 
-#     def func(*params: torch.Tensor):
-#         _output = _stateless.functional_call(
-#             module, {n: p for n, p in zip(keys, params)}, _input)
-#         return _output.log_softmax(dim=1)  # (N, C)
-#     jacobian_list: tuple[torch.Tensor] = torch.autograd.functional.jacobian(
-#         func, values)
+    with torch.no_grad():
+        _output: torch.Tensor = module(_input)  # (N, C)
+        prob = _output.softmax(dim=1).unsqueeze(-1).unsqueeze(-1)  # (N, C, 1, 1)
 
-#     fim_list: list[torch.Tensor] = []
-#     for jacobian in jacobian_list:  # TODO: parallel
-#         jacobian = jacobian.flatten(start_dim=2)   # (N, C, D)
-#         fim = prob * jacobian.unsqueeze(-1) * \
-#             jacobian.unsqueeze(-2)  # (N, C, D, D)
-#         fim_list.append(fim.sum(1).mean(0))   # (D, D)
-#     return fim_list
+    def func(*params: torch.Tensor):
+        _output: torch.Tensor = _stateless.functional_call(
+            module, {n: p for n, p in zip(keys, params)}, _input)
+        return _output.log_softmax(dim=1)  # (N, C)
+    jac: tuple[torch.Tensor] = torch.autograd.functional.jacobian(
+        func, values)
+    jac = (j.flatten(2) for j in jac)   # (N, C, D)
+
+    fim_list: list[torch.Tensor] = []
+    for j in jac:  # TODO: parallel
+        fim = prob * j.unsqueeze(-1) * \
+            j.unsqueeze(-2)  # (N, C, D, D)
+        fim_list.append(fim.sum(1).mean(0))   # (D, D)
+    return fim_list
